==> tetzle_2.1.6.orig.tar.gz: tetzle-2.1.6/translations/tetzle_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Abrir Imagem</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Aparência:</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Bordas arredondadas</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Sombras</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Cores</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Fundo:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Sombra:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Destaque:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Imagem em falta</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Por Favor Aguarde</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>A carregar imagem...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>A gerar o quebra-cabeças...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>A criar as peças...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>A carregar o quebra-cabeças...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Formato de dados desconhecido</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Elemento desconhecido &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Surgiu um erro ao processar o ficheiro XML.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>A carregar as peças...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>A obter as peças...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>A colocar as peças...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Sucesso</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Escolha o Jogo</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Jogos Atuais</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Novo Jogo</translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Propriedades da Imagem</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Etiquetas:</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selecione o idioma da aplicação:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma do Sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Por favor reinicie esta aplicação para que a alteração do idioma surta efeito.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Adicionar Imagem</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Remover Imagem</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Propriedades da Imagem</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 peças</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>A copiar as imagens...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Remove selected image?</source>
        <translation>Remover a imagem selecionada?</translation>
    </message>
    <message>
        <source>Remove selected image?

There are saved games using this image that will also be removed.</source>
        <translation>Remover a imagem selecionada?

Existem jogos guardados que usam esta imagem, por isso serão também removidos.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sem título</translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Sem título</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 peças %2 %3% completado</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Eliminar Jogo</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Eliminar o jogo selecionado?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Vista geral</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Adicionar Etiqueta</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Remover Etiqueta</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Sem Etiquetas</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Todas as Imagens</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Sem título %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Questão</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Remover etiqueta selecionada?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Desculpe</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Já existe uma etiqueta com esse nome.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Jogo</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Recuperar Peças</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Escolher Jogo...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Visualização</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>A&amp;proximar</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>A&amp;fastar</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>&amp;Melhor Enquadramento</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Mostrar &amp;Vista Geral</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>Ecrã &amp;Inteiro</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configurações</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Aparência...</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Idioma...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Controlos</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>S&amp;obre</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Sobre o &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controlos</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Pegar nas Peças:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Clique Esquerdo ou Tecla de Espaço</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Largar Peças:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Selecionar Peças:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Arrastar Esquerdo</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Rodar Peças:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Clique Direito, Ctrl+Clique Esquerdo, ou R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Arrastar Quebra-Cabeças:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Clique do Meio, Shift+Clique Esquerdo, ou teclas de Direção</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Magnificação:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Roda do rato ou +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Mover Cursor:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Mover rato ou teclas W,A,D,S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Sobre o Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Um quebra-cabeça com peças tetraminós</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Direitos de autor &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Lançado sob a licença &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>??%</source>
        <translation>??%</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Select OpenGL version.</source>
        <translation>Selecionar verão OpenGL.</translation>
    </message>
    <message>
        <source>version</source>
        <translation>versão</translation>
    </message>
</context>
</TS>

==> tetzle_3.0.1.orig.tar.gz: tetzle-3.0.1/translations/tetzle_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Abrir Imagem</translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Aparência:</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Bordas arredondadas</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Sombras</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Cores</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Fundo:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Sombra:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Destaque:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Imagem em falta</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Por Favor Aguarde</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>A carregar imagem...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>A gerar o quebra-cabeças...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>A criar as peças...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>A carregar o quebra-cabeças...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Formato de dados desconhecido</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Elemento desconhecido &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Surgiu um erro ao processar o ficheiro XML.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>A carregar as peças...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>A obter as peças...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>A colocar as peças...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Sucesso</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Escolha o Jogo</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Jogos Atuais</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Novo Jogo</translation>
    </message>
    <message>
        <source>Play Game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Propriedades da Imagem</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Etiquetas:</translation>
    </message>
    <message>
        <source>New tag name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selecione o idioma da aplicação:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma do Sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Por favor reinicie esta aplicação para que a alteração do idioma surta efeito.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Adicionar Imagem</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Remover Imagem</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Propriedades da Imagem</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 peças</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>A copiar as imagens...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sem título</translation>
    </message>
    <message numerus="yes">
        <source>Remove %n selected image(s)?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Saved games using these image(s) will be deleted.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Sem título</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 peças %2 %3% completado</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Eliminar Jogo</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Eliminar o jogo selecionado?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Vista geral</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Adicionar Etiqueta</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Remover Etiqueta</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Sem Etiquetas</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Todas as Imagens</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Sem título %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Questão</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Remover etiqueta selecionada?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Desculpe</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Já existe uma etiqueta com esse nome.</translation>
    </message>
    <message>
        <source>Manage Tags...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Jogo</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Recuperar Peças</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Escolher Jogo...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Visualização</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>A&amp;proximar</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>A&amp;fastar</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>&amp;Melhor Enquadramento</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Mostrar &amp;Vista Geral</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>Ecrã &amp;Inteiro</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configurações</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Aparência...</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Idioma...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Controlos</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>S&amp;obre</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Sobre o &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controlos</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Pegar nas Peças:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Clique Esquerdo ou Tecla de Espaço</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Largar Peças:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Selecionar Peças:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Arrastar Esquerdo</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Rodar Peças:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Clique Direito, Ctrl+Clique Esquerdo, ou R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Arrastar Quebra-Cabeças:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Clique do Meio, Shift+Clique Esquerdo, ou teclas de Direção</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Magnificação:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Roda do rato ou +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Mover Cursor:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Mover rato ou teclas W,A,D,S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Sobre o Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Um quebra-cabeça com peças tetraminós</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Direitos de autor &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Lançado sob a licença &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>%p% complete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>Zoom: %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
